@@ -14,13 +14,6 @@ if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
     exit;
 }
 
-$nonce = $_SERVER['HTTP_X_NONCE'] ?? '';
-if ($nonce !== $_SESSION['nonce']) {
-    $response['error'] = 'Invalid nonce';
-    echo json_encode($response);
-    exit;
-}
-
 try {
     $db = new PDO("mysql:host=localhost;dbname=whp;charset=utf8mb4", MYSQL_USER, MYSQL_PASS);
     $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
