@@ -114,9 +114,16 @@ $pdo = $MySQLMgmt->getMySQLConnection();
                             <h6><i class="bi bi-info-circle"></i> Upload Instructions</h6>
                             <p><strong>Before using this tool:</strong></p>
                             <ol class="mb-2">
+                                <?php if (AUTH_USER === 'root'): ?>
+                                <li>Select the target user account above</li>
+                                <li>Upload the cPanel backup (.tar.gz or .tgz) file to the user's <strong>userfiles</strong> directory</li>
+                                <li>You can access userfiles through the File Manager or FTP at: <code>/userfiles/</code> for each user</li>
+                                <li>Once uploaded, the backup files will appear in the dropdown below</li>
+                                <?php else: ?>
                                 <li>Upload your cPanel backup (.tar.gz or .tgz) file to your <strong>userfiles</strong> directory</li>
                                 <li>You can access userfiles through the File Manager or FTP at: <code>/userfiles/</code></li>
                                 <li>Once uploaded, refresh this page and select your backup file below</li>
+                                <?php endif; ?>
                             </ol>
                             <p class="mb-0"><strong>This tool will import:</strong> Domains, website files, MySQL databases, and create DNS records. SSL certificates are handled automatically by our system.</p>
                         </div>
@@ -219,9 +226,12 @@ $pdo = $MySQLMgmt->getMySQLConnection();
 
         // Load backup files on page load
         document.addEventListener('DOMContentLoaded', function() {
-            refreshBackupFiles();
             <?php if (AUTH_USER === 'root'): ?>
+            // For root, load users first, then backup files will load when user is selected
             loadUsers();
+            <?php else: ?>
+            // For regular users, load backup files immediately
+            refreshBackupFiles();
             <?php endif; ?>
         });
 
@@ -251,6 +261,18 @@ $pdo = $MySQLMgmt->getMySQLConnection();
                         option.textContent = user;
                         userSelect.appendChild(option);
                     });
+                    
+                    // Add event listener to refresh backup files when user changes
+                    userSelect.addEventListener('change', function() {
+                        if (this.value) {
+                            refreshBackupFiles();
+                        } else {
+                            // Clear backup files if no user selected
+                            const backupSelect = document.getElementById('backup_file_select');
+                            backupSelect.innerHTML = '<option value="">Select a user first</option>';
+                            document.getElementById('select-backup-btn').disabled = true;
+                        }
+                    });
                 } else {
                     userSelect.innerHTML = '<option value="">Failed to load users</option>';
                 }
@@ -264,15 +286,30 @@ $pdo = $MySQLMgmt->getMySQLConnection();
         // Refresh backup files list
         async function refreshBackupFiles() {
             try {
+                const params = {
+                    action: 'get_backup_files',
+                    nonce: nonce
+                };
+                
+                <?php if (AUTH_USER === 'root'): ?>
+                // For root, include the selected target user
+                const targetUserSelect = document.getElementById('target_user_select');
+                if (targetUserSelect && targetUserSelect.value) {
+                    params.target_user = targetUserSelect.value;
+                } else if (targetUserSelect && !targetUserSelect.value) {
+                    // No user selected yet, show message
+                    const backupSelect = document.getElementById('backup_file_select');
+                    backupSelect.innerHTML = '<option value="">Select a user first</option>';
+                    return;
+                }
+                <?php endif; ?>
+                
                 const response = await fetch('/api/cpanel-import-ajax.php', {
                     method: 'POST',
                     headers: {
                         'Content-Type': 'application/x-www-form-urlencoded',
                     },
-                    body: new URLSearchParams({
-                        action: 'get_backup_files',
-                        nonce: nonce
-                    })
+                    body: new URLSearchParams(params)
                 });
 
                 const result = await response.json();
